==> com.liferay.frontend.js.loader.modules.extender-6.0.9-sources-commercial.jar: com/liferay/frontend/js/loader/modules/extender/internal/npm/NPMResolverServiceFactory.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.frontend.js.loader.modules.extender.internal.npm;

import com.liferay.frontend.js.loader.modules.extender.npm.NPMRegistry;
import com.liferay.frontend.js.loader.modules.extender.npm.NPMResolver;
import com.liferay.portal.kernel.json.JSONException;
import com.liferay.portal.kernel.json.JSONFactory;
import com.liferay.portal.kernel.json.JSONObject;
import com.liferay.portal.kernel.util.StringUtil;

import java.io.IOException;

import java.net.URL;

import java.util.Hashtable;

import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceFactory;
import org.osgi.framework.ServiceRegistration;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Deactivate;
import org.osgi.service.component.annotations.Reference;
import org.osgi.service.component.annotations.ReferencePolicy;
import org.osgi.service.component.annotations.ReferencePolicyOption;

/**
 * @author Iván Zaera Avellón
 */
@Component(immediate = true, service = ServiceFactory.class)
public class NPMResolverServiceFactory implements ServiceFactory<NPMResolver> {

	@Override
	public NPMResolver getService(
		Bundle bundle, ServiceRegistration<NPMResolver> serviceRegistration) {

		URL packageURL = bundle.getEntry("META-INF/resources/package.json");

		if (packageURL == null) {
			return new InvalidNPMResolverImpl(bundle);
		}

		JSONObject packageJSONObject = _createJSONObject(packageURL);

		URL manifestURL = bundle.getEntry("META-INF/resources/manifest.json");

		if (manifestURL == null) {
			return new UnsupportedNPMResolverImpl(bundle);
		}

		JSONObject manifestJSONObject = _createJSONObject(manifestURL);

		JSONObject packagesJSONObject = manifestJSONObject.getJSONObject(
			"packages");

		if (packagesJSONObject == null) {
			return new UnsupportedNPMResolverImpl(bundle);
		}

		return new NPMResolverImpl(
			bundle, _npmRegistry, packageJSONObject, packagesJSONObject);
	}

	@Override
	public void ungetService(
		Bundle bundle, ServiceRegistration<NPMResolver> serviceRegistration,
		NPMResolver npmResolver) {
	}

	@Activate
	protected void activate(BundleContext bundleContext) {
		_serviceRegistration = bundleContext.registerService(
			NPMResolver.class, this, new Hashtable<String, Object>());
	}

	@Deactivate
	protected void deactivate() {
		_serviceRegistration.unregister();
	}

	private JSONObject _createJSONObject(URL url) {
		try {
			return _jsonFactory.createJSONObject(
				StringUtil.read(url.openStream()));
		}
		catch (IOException | JSONException exception) {
			throw new RuntimeException("Unable to read " + url, exception);
		}
	}

	@Reference(
		policy = ReferencePolicy.DYNAMIC,
		policyOption = ReferencePolicyOption.GREEDY
	)
	private volatile JSONFactory _jsonFactory;

	@Reference(
		policy = ReferencePolicy.DYNAMIC,
		policyOption = ReferencePolicyOption.GREEDY
	)
	private volatile NPMRegistry _npmRegistry;

	private ServiceRegistration<NPMResolver> _serviceRegistration;

}

==> com.liferay.frontend.js.loader.modules.extender-6.0.34-sources-commercial.jar: com/liferay/frontend/js/loader/modules/extender/internal/npm/NPMResolverServiceFactory.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.frontend.js.loader.modules.extender.internal.npm;

import com.liferay.frontend.js.loader.modules.extender.npm.NPMRegistry;
import com.liferay.frontend.js.loader.modules.extender.npm.NPMResolver;
import com.liferay.portal.kernel.json.JSONException;
import com.liferay.portal.kernel.json.JSONFactory;
import com.liferay.portal.kernel.json.JSONObject;
import com.liferay.portal.kernel.util.StringUtil;

import java.io.IOException;

import java.net.URL;

import org.osgi.framework.Bundle;
import org.osgi.framework.ServiceFactory;
import org.osgi.framework.ServiceRegistration;

/**
 * @author Iván Zaera Avellón
 */
public class NPMResolverServiceFactory implements ServiceFactory<NPMResolver> {

	public NPMResolverServiceFactory(
		JSONFactory jsonFactory, NPMRegistry npmRegistry) {

		_jsonFactory = jsonFactory;
		_npmRegistry = npmRegistry;
	}

	@Override
	public NPMResolver getService(
		Bundle bundle, ServiceRegistration<NPMResolver> serviceRegistration) {

		URL packageURL = bundle.getEntry("META-INF/resources/package.json");

		if (packageURL == null) {
			return new InvalidNPMResolverImpl(bundle);
		}

		JSONObject packageJSONObject = _createJSONObject(packageURL);

		URL manifestURL = bundle.getEntry("META-INF/resources/manifest.json");

		if (manifestURL == null) {
			return new UnsupportedNPMResolverImpl(bundle);
		}

		JSONObject manifestJSONObject = _createJSONObject(manifestURL);

		JSONObject packagesJSONObject = manifestJSONObject.getJSONObject(
			"packages");

		if (packagesJSONObject == null) {
			return new UnsupportedNPMResolverImpl(bundle);
		}

		return new NPMResolverImpl(
			bundle, _npmRegistry, packageJSONObject, packagesJSONObject);
	}

	@Override
	public void ungetService(
		Bundle bundle, ServiceRegistration<NPMResolver> serviceRegistration,
		NPMResolver npmResolver) {
	}

	private JSONObject _createJSONObject(URL url) {
		try {
			return _jsonFactory.createJSONObject(
				StringUtil.read(url.openStream()));
		}
		catch (IOException | JSONException exception) {
			throw new RuntimeException("Unable to read " + url, exception);
		}
	}

	private final JSONFactory _jsonFactory;
	private final NPMRegistry _npmRegistry;

}
